.. include:: ../README.rst


.. toctree::
   :maxdepth: 2
   :caption: Project Operations

   versioning
   changelog

.. toctree::
   :maxdepth: 2
   :caption: Usage

   by_example/index
   api/index
